#
# spec file for package python-nagiosplugin
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python36 1
Name:           python-nagiosplugin
Version:        1.3.3
Release:        1.7
Summary:        Class library for writing Nagios (Icinga) plugins
License:        ZPL-2.1
URL:            https://github.com/mpounsett/nagiosplugin
Source:         https://files.pythonhosted.org/packages/source/n/nagiosplugin/nagiosplugin-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
nagiosplugin is a Python class library which helps writing Nagios (or Icinga)
compatible plugins in Python. It cares for much of the boilerplate code
and default logic commonly found in Nagios checks, including:

- Nagios 3 Plugin API compliant parameters and output formatting
- Full Nagios range syntax support
- Automatic threshold checking
- Multiple independent measures
- Custom status line to communicate the main point quickly
- Long output and performance data
- Timeout handling
- Persistent "cookies" to retain state information between check runs
- Resumption of log file processing at the point where the last run left off
- No dependencies beyond the Python standard library

%prep
%setup -q -n nagiosplugin-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# skip because of gh#mpounsett/nagiosplugin#53
%pytest -k 'not test_check_users'

%files %{python_files}
%license LICENSE.txt
%doc README.txt
%{python_sitelib}/nagiosplugin
%{python_sitelib}/nagiosplugin-%{version}*-info

%changelog
* Wed Nov  6 2024 Matej Cepl <mcepl@cepl.eu>
- Skip the failing test test_check_users (gh#mpounsett/nagiosplugin#53)
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 1.3.3 (2022-02-07)
  * new: adding support for newer python releases (3.8, 3.9, 3.10)
  * fix: various typos in docstrings (#39, )
  * fix: change use of deprecated upload-dir to upload_dir in setup.cfg (#34)
  * fix: Runtime class now sets None for stdout by default (#24)
  * fix: corrected argument order in several calls to super() (#18)
  * cleanup: many bits of code tidying to eliminate linter warnings
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Mon Mar 30 2020 pgajdos@suse.com
- version update to 1.3.2
  - Include `doc` and `tests` directories in source distribution to support
    Gentoo package building tests (#22)
  - Update official python support to 2.7, 3.4+ in README
  - Fixed a packaging bug
  - New maintainer/contributor information and project home
  - Updated tests and package metadata for recent Python 3 versions
  - Newer tooling for tests/documentation
* Thu May  2 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias/spellos from description.
* Fri Aug 25 2017 mardnh@gmx.de
- Initial package, version 1.2.4
